summaryrefslogtreecommitdiffstats
path: root/net/base/ssl_connection_status_flags.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/base/ssl_connection_status_flags.h')
-rw-r--r--net/base/ssl_connection_status_flags.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/net/base/ssl_connection_status_flags.h b/net/base/ssl_connection_status_flags.h
index 9596f00..bf349ce 100644
--- a/net/base/ssl_connection_status_flags.h
+++ b/net/base/ssl_connection_status_flags.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -18,8 +18,8 @@ enum {
SSL_CONNECTION_COMPRESSION_SHIFT = 16,
SSL_CONNECTION_COMPRESSION_MASK = 3,
- // We fell back to SSLv3 for this connection.
- SSL_CONNECTION_SSL3_FALLBACK = 1 << 18,
+ // We fell back to an older protocol version for this connection.
+ SSL_CONNECTION_VERSION_FALLBACK = 1 << 18,
// The server doesn't support the renegotiation_info extension. If this bit
// is not set then either the extension isn't supported, or we don't have any